@@ -4,4 +4,8 @@
 
 __author__ = """into-ai"""
 __email__ = "introintoai@gmail.com"
-__version__ = "0.1.0"
+__version__ = "0.3.1"
+
+from deeplearning2020.submission import Submission as _Submission
+
+Submission = _Submission
